@@ -2,8 +2,8 @@
  * This file is part of signon
  *
  * Copyright (C) 2009-2010 Nokia Corporation.
+ * Copyright (C) 2015-2016 Canonical Ltd.
  *
- * Contact: Aurel Popirtac <ext-aurel.popirtac@nokia.com>
  * Contact: Alberto Mardegan <alberto.mardegan@canonical.com>
  *
  * This library is free software; you can redistribute it and/or
@@ -28,26 +28,6 @@
 #ifndef LIBSIGNONCOMMON_H
 #define LIBSIGNONCOMMON_H
 
-#ifdef LIBSIGNON_TRACE
-    #include <QDebug>
-
-    #ifdef DEBUG_ENABLED
-        #ifdef TRACE
-            #undef TRACE
-        #endif
-
-        #ifdef BLAME
-            #undef BLAME
-        #endif
-
-        #define TRACE() qDebug() << __FILE__ << __LINE__ << __func__
-        #define BLAME() qCritical() << __FILE__ << __LINE__ << __func__
-    #else
-        #define TRACE() while (0) qDebug()
-        #define BLAME() while (0) qCritical()
-    #endif
-#endif
-
 #ifdef SIGNON_EXPORT
     #undef SIGNON_EXPORT
 #endif
@@ -60,10 +40,4 @@
     #define SIGNON_EXPORT
 #endif
 
-/*
-   TODO - Add here a common data container for IdentityInfo,
-          dbus register it and use it as qt dbus type
-          for the signond <--> libsignon communication
-*/
-
 #endif // LIBSIGNONCOMMON_H
